Django-flash --- Rails-like flash scope support for Django
==============================================================

Django-flash is a simple extension to the Django_ framework which enables the
use of the so called **flash scope**, first introduced by `Ruby on Rails`_ a
few years ago.

This is an open source project licenced under the terms of the
`Lesser General Public License v3.0`_ and sponsored by
`Destaquenet Technology Solutions`_, a brazilian software development and
consultancy startup.

  .. seealso::
     `PDF version <http://djangoflash.destaquenet.com/django-flash.pdf>`_ of
     this documentation.


Documentation contents
----------------------

.. toctree::
   :maxdepth: 3

   installation
   configuration
   usage
   modules/index
   changelog


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Contact information
-------------------

  :Author: Daniel Fernandes Martins <daniel@destaquenet.com>
  :Company: `Destaquenet Technology Solutions`_


.. _Lesser General Public License v3.0: http://www.gnu.org/licenses/lgpl-3.0.html
.. _Django: http://www.djangoproject.org/
.. _Ruby on Rails: http://www.rubyonrails.org/
.. _Destaquenet Technology Solutions: http://www.destaquenet.com/

